import { Application } from "express";
import addUser from "../middlewares/user/addUser";
import addWarning from "../middlewares/user/addWarning";
import authenticated from "../middlewares/auth/authenticated";
import deleteUser from "../middlewares/user/deleteUser";
import deleteWarning from "../middlewares/user/deleteWarning";
import emptyResponse from "../middlewares/utils/emptyResponse";
import getOwnUser from "../middlewares/user/getOwnUser";
import getUser from "../middlewares/user/getUser";
import getUsersList from "../middlewares/user/getUsersList";
import getWarning from "../middlewares/user/getWarning";
import getWarningsList from "../middlewares/user/getWarningsList";
import responseUser from "../middlewares/user/responseUser";
import responseUserList from "../middlewares/user/responseUserList";
import updateUser from "../middlewares/user/updateUser";
import updateWarning from "../middlewares/user/updateWarning";

const usersRoute = (app: Application): void => {
  app.get("/api/v1/users", authenticated(), getUsersList(), responseUserList());

  app.post("/api/v1/users", authenticated(), addUser(), responseUser());

  app.get("/api/v1/users/me", getOwnUser(), responseUser());

  app.get("/api/v1/users/:id", getUser(), responseUser());

  app.get("/api/v1/users/:id/warnings", getWarningsList());

  app.get("/api/v1/users/:userId/warnings/:warningId", getWarning());

  app.post("/api/v1/users/:id/warnings", addWarning());

  app.put("/api/v1/users/:id", updateUser(), responseUser());

  app.put("/api/v1/users/:userId/warnings/:warningId", updateWarning());

  app.delete("/api/v1/users/:id", deleteUser(), emptyResponse());

  app.delete("/api/v1/users/:userId/warnings/:warningId", deleteWarning());
};

export default usersRoute;
